@@ -22,6 +22,7 @@
   2003/01/20 - NAME_MAX Fix by Hal Pomeranz
   2003/09/01 - BSDI port by Nelson Murilo and Thomas Davidson
   2005/22/05 - APPLE test for limits.h included by Aaron Harwood
+  2007/08/10 - strncpy used instead of strcpy
 
 */
 
@@ -76,7 +77,7 @@ char *make_pathname (char *path, char *dir, char **buffer)
     offs = 0;
   }
   else {
-    strcpy(*buffer, path);
+    strncpy(*buffer, path, bufsize);
     if ((*buffer)[plen-1] == '/') {   /* "path" ends in "/", don't add extra */
       offs = plen;
     }
@@ -85,7 +86,7 @@ char *make_pathname (char *path, char *dir, char **buffer)
       offs = plen + 1;
     }
   }
-  strcpy((*buffer)+offs, dir);
+  strncpy((*buffer)+offs, dir, bufsize - offs);
   return((*buffer));
 }
 
@@ -128,7 +129,7 @@ int check_dir (char *dir, char *path, int linkcount, int norecurse)
       fprintf(stderr, "malloc() failed: %s\n", strerror(errno));
       return(-1);
     }
-    strcpy(curpath, path);
+    strncpy(curpath, path, plen+1);
   }
 
   /* Now set "fullpath" to be the absolute path name of the directory
@@ -201,7 +202,7 @@ int check_dir (char *dir, char *path, int linkcount, int norecurse)
 	  continue;
 	}
 
-	strcpy(dl->dil_name, finfo->d_name);
+	strncpy(dl->dil_name, finfo->d_name, sizeof(dl->dil_name));
 	dl->dil_lc = statinfo.st_nlink;
 	dl->dil_next = dptr;
       }
