@@ -181,7 +181,7 @@ int main(int argc, char*argv[]) {
                         if (lastlog_ent.ll_time == 0)
                         {
                            if (-1 != (slot = getslot(localpwd, *uid)))
-                               printf("user %s deleted or never loged from lastlog!\n",
+                               printf("user %s deleted or never logged from lastlog!\n",
                                 NULL != localpwd->uname[slot] ?
                                 (char*)localpwd->uname[slot] : "(null)");
                            else
